# Generated by Django 4.0.6 on 2022-10-15 04:35

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Lingua',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('naran', models.CharField(max_length=255)),
                ('icon', models.ImageField(blank=True, default='pajina/default.jpg', null=True, upload_to='lingua/')),
            ],
            options={
                'verbose_name_plural': 'Lingua',
            },
        ),
        migrations.CreateModel(
            name='Munisipiu',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('naran', models.CharField(max_length=255)),
                ('date_created', models.DateField(blank=True, null=True, verbose_name='Data Rejistu')),
                ('hashed', models.TextField(blank=True, null=True)),
            ],
            options={
                'verbose_name_plural': 'Munisipiu',
            },
        ),
        migrations.CreateModel(
            name='Postu',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('naran', models.CharField(max_length=255)),
                ('date_created', models.DateField(blank=True, null=True, verbose_name='Data Rejistu')),
                ('hashed', models.TextField(blank=True, null=True)),
                ('munisipiu', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='jeral.munisipiu', verbose_name='Hili Munisipiu')),
            ],
            options={
                'verbose_name_plural': 'Postu',
            },
        ),
        migrations.CreateModel(
            name='Suku',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('naran', models.CharField(max_length=255)),
                ('date_created', models.DateField(blank=True, null=True, verbose_name='Data Rejistu')),
                ('hashed', models.TextField(blank=True, null=True)),
                ('postu', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='jeral.postu', verbose_name='Hili Postu')),
            ],
            options={
                'verbose_name_plural': 'Suku',
            },
        ),
    ]
